from setuptools import setup, find_packages


setup(
    name='UNKnownDB',
    version='1.6.1',
    author='CleaverCreator',
    author_email='liuhanbo333@icloud.com',
    packages=find_packages(),
    zip_safe=False,
    platforms=['Linux'],
    install_requires=['PyQt5'],
    description='A new Python DB',
    long_description="""
                    A DB that human can read
                    'Use Unknown Describe Language
                                    """,
    license='GIL',
    url='https://github.com/CleverCreater/UNKnownDB',
    classifiers=[]
)
